# -*- coding: iso-8859-3 -*-
# Protect things like [^g] or [^j], which mean not{g,j}
s/\[^/\[\$\$/g
# Now real hat2latin3 stuff
s/\^c/æ/g
s/\^g/ø/g
s/\^h/¶/g
s/\^j/¼/g
s/\^s/þ/g
s/\^u/ý/g
s/\^C/Æ/g
s/\^G/Ø/g
s/\^H/¦/g
s/\^J/¬/g
s/\^S/Þ/g
s/\^U/Ý/g
# Undo above protection
s/\[\$\$/\[^/g
# Some words in eo.dic are written in TeX encoding. Convert to latin3
s/\\"u/ü/g
s/\\c{c}/ç/g
s/\\'a/á/g
